#include <QApplication>

#include "readwidget.h"
#include "control.h"
#include "booklistwidget.h"

int main(int argc,char* argv[])
{
    QApplication app(argc,argv);
    app.setApplicationName("AudiobookReader");

    Control controlWindow;
    //controlWindow.show();

    app.exec();
}

